==> dokuwiki-2015.08.10a.tgz: dokuwiki/lib/plugins/acl/lang/de/lang.php <==
<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * 
 * @author Andreas Gohr <andi@splitbrain.org>
 * @author Christof <gagi@fin.de>
 * @author Anika Henke <anika@selfthinker.org>
 * @author Esther Brunner <esther@kaffeehaus.ch>
 * @author Matthias Grimm <matthiasgrimm@users.sourceforge.net>
 * @author Michael Klier <chi@chimeric.de>
 * @author Leo Moll <leo@yeasoft.com>
 * @author Florian Anderiasch <fa@art-core.org>
 * @author Robin Kluth <commi1993@gmail.com>
 * @author Arne Pelka <mail@arnepelka.de>
 * @author Dirk Einecke <dirk@dirkeinecke.de>
 * @author Blitzi94@gmx.de
 * @author Robert Bogenschneider <robog@GMX.de>
 * @author Robert Bogenschneider <robog@gmx.de>
 * @author Niels Lange <niels@boldencursief.nl>
 * @author Christian Wichmann <nospam@zone0.de>
 * @author Paul Lachewsky <kaeptn.haddock@gmail.com>
 * @author Pierre Corell <info@joomla-praxis.de>
 */
$lang['admin_acl']             = 'Zugangsverwaltung';
$lang['acl_group']             = 'Gruppe:';
$lang['acl_user']              = 'Benutzer:';
$lang['acl_perms']             = 'Berechtigungen für';
$lang['page']                  = 'Seite';
$lang['namespace']             = 'Namensraum';
$lang['btn_select']            = 'Auswählen';
$lang['p_user_id']             = 'Nutzer <b class="acluser">%s</b> hat momentan folgende Berechtigungen für die Seite <b class="aclpage">%s</b>: <i>%s</i>.';
$lang['p_user_ns']             = 'Nutzer <b class="acluser">%s</b> hat momentan folgende Berechtigungen im Namensraum <b class="aclns">%s</b>: <i>%s</i>.';
$lang['p_group_id']            = 'Mitglieder der Gruppe <b class="aclgroup">%s</b> haben momentan folgende Berechtigungen für die Seite <b class="aclpage">%s</b>: <i>%s</i>.';
$lang['p_group_ns']            = 'Mitglieder der Gruppe <b class="aclgroup">%s</b> haben momentan folgende Berechtigungen für den Namensraum <b class="aclns">%s</b>: <i>%s</i>.';
$lang['p_choose_id']           = 'Bitte geben Sie in obigem Formular eine <b>einen Benutzer oder eine Gruppe</b> an, um die Berechtigungen für die Seite <b class="aclpage">%s</b> zu sehen oder zu ändern.';
$lang['p_choose_ns']           = 'Bitte geben Sie in obigem Formular eine <b>einen Benutzer oder eine Gruppe</b> an, um die Berechtigungen für den Namensraum <b class="aclns">%s</b> zu sehen oder zu ändern.';
$lang['p_inherited']           = 'Hinweis: Diese Berechtigungen wurden nicht explizit gesetzt, sondern von anderen Gruppen oder höher liegenden Namensräumen geerbt.';
$lang['p_isadmin']             = 'Hinweis: Die ausgewählte Gruppe oder Benutzer haben immer alle Berechtigungen das sie als Superuser konfiguriert wurden.';
$lang['p_include']             = 'Höhere Berechtigungen schließen niedrigere mit ein. Anlegen, Hochladen und Entfernen gilt nur für Namensräume, nicht für einzelne Seiten';
$lang['current']               = 'Momentane Zugriffsregeln';
$lang['where']                 = 'Seite/Namensraum';
$lang['who']                   = 'Nutzer/Gruppe';
$lang['perm']                  = 'Berechtigungen';
$lang['acl_perm0']             = 'Keine';
$lang['acl_perm1']             = 'Lesen';
$lang['acl_perm2']             = 'Bearbeiten';
$lang['acl_perm4']             = 'Anlegen';
$lang['acl_perm8']             = 'Hochladen';
$lang['acl_perm16']            = 'Entfernen';
$lang['acl_new']               = 'Eintrag hinzufügen';
$lang['acl_mod']               = 'Eintrag bearbeiten';

==> dokuwiki-2024.02.06.tgz: dokuwiki/lib/plugins/acl/lang/de/lang.php <==
<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 *
 * @author Robert Riebisch <rr@bttr-software.de>
 * @author Andreas Gohr <andi@splitbrain.org>
 * @author Christof <gagi@fin.de>
 * @author Anika Henke <anika@selfthinker.org>
 * @author Esther Brunner <esther@kaffeehaus.ch>
 * @author Matthias Grimm <matthiasgrimm@users.sourceforge.net>
 * @author Michael Klier <chi@chimeric.de>
 * @author Leo Moll <leo@yeasoft.com>
 * @author Florian Anderiasch <fa@art-core.org>
 * @author Robin Kluth <commi1993@gmail.com>
 * @author Arne Pelka <mail@arnepelka.de>
 * @author Dirk Einecke <dirk@dirkeinecke.de>
 * @author Blitzi94 <Blitzi94@gmx.de>
 * @author Robert Bogenschneider <robog@GMX.de>
 * @author Niels Lange <niels@boldencursief.nl>
 * @author Christian Wichmann <nospam@zone0.de>
 * @author Paul Lachewsky <kaeptn.haddock@gmail.com>
 * @author Pierre Corell <info@joomla-praxis.de>
 * @author Michael Große <grosse@cosmocode.de>
 */
$lang['admin_acl']             = 'Zugangsverwaltung';
$lang['acl_group']             = 'Gruppe:';
$lang['acl_user']              = 'Benutzer:';
$lang['acl_perms']             = 'Berechtigungen für';
$lang['page']                  = 'Seite';
$lang['namespace']             = 'Namensraum';
$lang['btn_select']            = 'Auswählen';
$lang['p_user_id']             = 'Nutzer <b class="acluser">%s</b> hat momentan folgende Berechtigungen für die Seite <b class="aclpage">%s</b>: <i>%s</i>.';
$lang['p_user_ns']             = 'Nutzer <b class="acluser">%s</b> hat momentan folgende Berechtigungen im Namensraum <b class="aclns">%s</b>: <i>%s</i>.';
$lang['p_group_id']            = 'Mitglieder der Gruppe <b class="aclgroup">%s</b> haben momentan folgende Berechtigungen für die Seite <b class="aclpage">%s</b>: <i>%s</i>.';
$lang['p_group_ns']            = 'Mitglieder der Gruppe <b class="aclgroup">%s</b> haben momentan folgende Berechtigungen für den Namensraum <b class="aclns">%s</b>: <i>%s</i>.';
$lang['p_choose_id']           = 'Bitte geben Sie in obigem Formular <b>einen Benutzer oder eine Gruppe</b> an, um die Berechtigungen für die Seite <b class="aclpage">%s</b> zu sehen oder zu ändern.';
$lang['p_choose_ns']           = 'Bitte geben Sie in obigem Formular <b>einen Benutzer oder eine Gruppe</b> an, um die Berechtigungen für den Namensraum <b class="aclns">%s</b> zu sehen oder zu ändern.';
$lang['p_inherited']           = 'Hinweis: Diese Berechtigungen wurden nicht explizit gesetzt, sondern von anderen Gruppen oder höher liegenden Namensräumen geerbt.';
$lang['p_isadmin']             = 'Hinweis: Die ausgewählte Gruppe oder Benutzer haben immer alle Berechtigungen, da sie als Superuser konfiguriert wurden.';
$lang['p_include']             = 'Höhere Berechtigungen schließen niedrigere mit ein. Anlegen, Hochladen und Entfernen gilt nur für Namensräume, nicht für einzelne Seiten';
$lang['current']               = 'Momentane Zugriffsregeln';
$lang['where']                 = 'Seite/Namensraum';
$lang['who']                   = 'Nutzer/Gruppe';
$lang['perm']                  = 'Berechtigungen';
$lang['acl_perm0']             = 'Keine';
$lang['acl_perm1']             = 'Lesen';
$lang['acl_perm2']             = 'Bearbeiten';
$lang['acl_perm4']             = 'Anlegen';
$lang['acl_perm8']             = 'Hochladen';
$lang['acl_perm16']            = 'Entfernen';
$lang['acl_new']               = 'Eintrag hinzufügen';
$lang['acl_mod']               = 'Eintrag bearbeiten';
